/***************************************************************************
 *   Weather module for Kadu communicator                                  *
 *   2004 Micha Maek (bysk)                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef AUTODOWNLOADER_H
#define AUTODOWNLOADER_H

#include <qobject.h>

#include "status_changer.h"
#include "get_forecast.h"
#include <memory>

class QTimer;

class WeatherStatusChanger : public StatusChanger
{
	Q_OBJECT
public:
	WeatherStatusChanger();
	void setDescription( const QString& description );
	void setEnabled( bool enabled );
	bool enabled() const					{ return enabled_; }

private:
	virtual void changeStatus( UserStatus& status );
	
private:
	QString description_;
	bool enabled_;
};

class AutoDownloader : public QObject
{
	Q_OBJECT
	
public:
	AutoDownloader();
	~AutoDownloader();
	
public slots:
	void parametersChanged();
	
private:
	QTimer* autoDownloadTimer_;
	std::auto_ptr<GetForecast> downloader_;
	std::auto_ptr<WeatherStatusChanger> statusChanger_;
	bool fetchingEnabled_;
	bool hintsEnabled_;
	bool descEnabled_;
	
	QString parse(const ForecastDay& day, QString str);

private slots:
	void autoDownload();
	void autoDownloadingFinished();
	
};

#endif // AUTODOWNLOADER_H
